@@ -10,14 +10,13 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate;
-$App::SpreadRevolutionaryDate::VERSION = '0.08';
+$App::SpreadRevolutionaryDate::VERSION = '0.09';
 # ABSTRACT: Spread date and time from Revolutionary (Republican) Calendar on Twitter, Mastodon and Freenode.
 
 use Moose;
 use namespace::autoclean;
 use App::SpreadRevolutionaryDate::Config;
 use DateTime::Calendar::FrenchRevolutionary;
-use URI::Escape;
 use Class::Load ':all';
 
 has 'config' => (
@@ -29,16 +28,29 @@ has 'config' => (
 has 'targets' => (
     is  => 'rw',
     isa => 'HashRef[Object]',
+    required => 1,
+);
+
+has 'msgmaker' => (
+    is  => 'rw',
+    isa => 'Object',
+    required => 1,
 );
 
 
 around BUILDARGS => sub {
-  my $orig = shift;
-  my $class = shift;
-  my $filename = shift;
+  my ($orig, $class, $filename) = @_;
+
   my $config = App::SpreadRevolutionaryDate::Config->new($filename);
 
-  return $class->$orig(config => $config, targets => {});
+  my $msgmaker_class = 'App::SpreadRevolutionaryDate::MsgMaker::' . $config->msgmaker;
+  try_load_class($msgmaker_class)
+    or die "Cannot import msgmaker class $msgmaker_class\n";
+  load_class($msgmaker_class);
+  my %msgmaker_args = $config->get_msgmaker_arguments($config->msgmaker);
+  my $msgmaker = $msgmaker_class->new(locale => $config->locale, %msgmaker_args);
+
+  return $class->$orig(config => $config, targets => {}, msgmaker => $msgmaker);
 };
 
 
@@ -59,35 +71,13 @@ sub BUILD {
 sub spread {
   my $self = shift;
 
-  my $msg = $self->compute();
+  my $msg = $self->msgmaker->compute();
   foreach my $target (@{$self->config->targets}) {
     $self->targets->{$target}->spread($msg, $self->config->test);
   }
 }
 
 
-sub compute {
-  my $self = shift;
-
-  # As of DateTime::Calendar::FrenchRevolutionary 0.14
-  # locale is limited to 'en' or 'fr', defaults to 'fr'
-  my $locale = $self->config->locale || 'fr';
-  $locale = 'fr' unless $locale eq 'en';
-
-  my $revolutionary = $self->config->acab ?
-      DateTime::Calendar::FrenchRevolutionary->now->set(hour => 1, minute => 31, second => 20, locale => $locale)
-    : DateTime::Calendar::FrenchRevolutionary->now->set(locale => $locale);
-
-  my $msg = $locale eq 'fr' ?
-      $revolutionary->strftime("Nous sommes le %A, %d %B de l'An %EY (%Y) de la Révolution, %Ej, il est %T! https://$locale.wikipedia.org/wiki/!!%Oj!!")
-    : $revolutionary->strftime("We are %A, %d %B of Revolution Year %EY (%Y), %Ej, it is %T! https://$locale.wikipedia.org/wiki/!!%Oj!!");
-
-  $msg =~ s/!!([^!]+)!!/uri_escape($1)/e;
-
-  return $msg
-}
-
-
 no Moose;
 __PACKAGE__->meta->make_immutable;
 
@@ -110,7 +100,7 @@ App::SpreadRevolutionaryDate - Spread date and time from Revolutionary (Republic
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 METHODS
 
@@ -126,10 +116,6 @@ Initialises the internal C<App::SpreadRevolutionaryDate> object. This is where a
 
 Spreads calendar date to configured targets. Takes no argument.
 
-=head2 compute
-
-Computes revolutionary date. Takes no argument. Returns message as string, ready to be spread.
-
 =head1 SEE ALSO
 
 =over
@@ -148,6 +134,12 @@ Computes revolutionary date. Takes no argument. Returns message as string, ready
 
 =item L<App::SpreadRevolutionaryDate::Target::Freenode::Bot>
 
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker>
+
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker::RevolutionaryDate>
+
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker::PromptUser>
+
 =back
 
 =head1 AUTHOR
