@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Config;
-$App::SpreadRevolutionaryDate::Config::VERSION = '0.08';
+$App::SpreadRevolutionaryDate::Config::VERSION = '0.09';
 # ABSTRACT: Companion class of L<App::SpreadRevolutionaryDate>, to handle configuration file and command line arguments, subclass of L<AppConfig>.
 
 use Moose;
@@ -24,6 +24,7 @@ use namespace::clean;
 
 sub new {
   my ($class, $filename) = @_;
+
   # If filename is not a file path but a GLOB or an opend filehandle
   # we'll need to rewind it to the beginning before reading it twice
   my $file_start;
@@ -33,11 +34,12 @@ sub new {
   my @orig_argv = @ARGV;
 
   # Find targets
-  my $config_targets = AppConfig::new($class, {CREATE => 1},
+  my $config_targets = AppConfig::new($class, {CREATE => 1, ERROR => sub {}},
                                       'targets' => {ARGCOUNT => ARGCOUNT_LIST, ALIAS => 'tg'},
-                                      'acab' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'a'},
+                                      'msgmaker' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'mm'},
                                       'test' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'no|n'},
                                       'locale' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'l'},
+                                      'acab' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'a'},
                                       'twitter' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 't'},
                                       'mastodon' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'm'},
                                       'freenode' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'f'});
@@ -52,7 +54,7 @@ sub new {
   foreach my $potential_target (keys %potential_targets) {
     next unless $potential_targets{$potential_target};
     next if $potential_target =~ /_/;
-    if ($potential_target !~ /^(?:acab|test|locale|targets)$/) {
+    if ($potential_target !~ /^(?:acab|test|locale|targets|msgmaker)$/) {
       push @targets, $potential_target;
     }
   }
@@ -79,19 +81,39 @@ sub new {
     foreach my $target_meta_attribute ($target_meta->get_all_attributes) {
       next if $target_meta_attribute->name eq 'obj';
       my $target_meta_attribute_type = $target_meta_attribute->type_constraint;
-      my $target_meta_attribute_argcount = $target_meta_attribute_type =~ /ArrayRef/ ? ARGCOUNT_LIST : $target_meta_attribute_type =~ /HashRef/ ? ARGCOUNT_HASH : ARGCOUNT_ONE;
-      $target_attributes{$target . '_' . $target_meta_attribute->name} = { ARGCOUNT => $target_meta_attribute_argcount };
-      $target_attributes{$target} = { ARGCOUNT => ARGCOUNT_NONE };
+      my $target_meta_attribute_argcount = $target_meta_attribute_type =~ /ArrayRef/ ? ARGCOUNT_LIST : $target_meta_attribute_type =~ /HashRef/ ? ARGCOUNT_HASH : $target_meta_attribute_type =~ /Bool/ ? ARGCOUNT_NONE : ARGCOUNT_ONE;
+      $target_attributes{lc($target) . '_' . $target_meta_attribute->name} = { ARGCOUNT => $target_meta_attribute_argcount };
+      $target_attributes{lc($target)} = { ARGCOUNT => ARGCOUNT_NONE };
     }
   }
 
+  # Guess attributes for MsgMaker
+  my %msgmaker_attributes;
+  my $msgmaker = $config_targets->msgmaker || 'RevolutionaryDate';
+  my $msgmaker_class = 'App::SpreadRevolutionaryDate::MsgMaker::' . $msgmaker;
+  my $msgmaker_meta;
+  try_load_class($msgmaker_class)
+    or die "Cannot found msgmaker class $msgmaker_class for msgmaker $msgmaker\n";
+  load_class($msgmaker_class);
+  eval { $msgmaker_meta = $msgmaker_class->meta; };
+  die "Cannot found msgmaker meta class $msgmaker_class for msgmaker $msgmaker: $@\n" if $@;
+  foreach my $msgmaker_meta_attribute ($msgmaker_meta->get_all_attributes) {
+    next if $msgmaker_meta_attribute->name eq 'locale';
+    my $msgmaker_meta_attribute_type = $msgmaker_meta_attribute->type_constraint;
+    my $msgmaker_meta_attribute_argcount = $msgmaker_meta_attribute_type =~ /ArrayRef/ ? ARGCOUNT_LIST : $msgmaker_meta_attribute_type =~ /HashRef/ ? ARGCOUNT_HASH : $msgmaker_meta_attribute_type =~ /Bool/ ? ARGCOUNT_NONE : ARGCOUNT_ONE;
+    $msgmaker_attributes{lc($msgmaker) . '_' . $msgmaker_meta_attribute->name} = { ARGCOUNT => $msgmaker_meta_attribute_argcount };
+    $msgmaker_attributes{lc($msgmaker)} = { ARGCOUNT => ARGCOUNT_NONE };
+  }
+
   # Build actual instance
   my $self = AppConfig::new($class,
     %target_attributes,
+    %msgmaker_attributes,
     'targets' => {ARGCOUNT => ARGCOUNT_LIST, ALIAS => 'tg'},
-    'acab' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'a'},
+    'msgmaker' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'mm', default => 'RevolutionaryDate'},
     'test' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'no|n'},
-    'locale' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'l'},
+    'locale' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'l', default => 'fr'},
+    'acab' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'a'},
     # Overwrite found attributes for default targets
     # for backward compatibility with aliases
     'twitter' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 't'},
@@ -127,7 +149,7 @@ sub new {
   foreach my $potential_target (keys %confvars) {
     next unless $confvars{$potential_target};
     next if $potential_target =~ /_/;
-    if ($potential_target !~ /^(?:acab|test|locale|targets)$/) {
+    if ($potential_target !~ /^(?:acab|test|locale|targets|msgmaker)$/) {
       push @targets, $potential_target;
       $self->targets($potential_target);
     }
@@ -147,13 +169,20 @@ sub new {
     $self->check_target_mandatory_options($target);
   }
 
+  # Add acab option for RevolutionaryDate for backward compatibility
+  $self->revolutionarydate_acab($self->acab)
+    if  $self->msgmaker eq 'RevolutionaryDate'
+        && !$self->revolutionarydate_acab
+        && $self->acab;
+
+
   return $self;
 }
 
 
 sub parse_file {
-  my $self = shift;
-  my $filename = shift;
+  my ($self, $filename) = @_;
+
   foreach my $default_path (
                 File::HomeDir->my_home . '/.config/spread-revolutionary-date/spread-revolutionary-date.conf',
                 File::HomeDir->my_home . '/.spread-revolutionary-date.conf') {
@@ -165,13 +194,13 @@ sub parse_file {
 
 sub parse_command_line {
   my $self = shift;
+
   $self->args;
 }
 
 
 sub check_target_mandatory_options {
-  my $self = shift;
-  my $target = shift;
+  my ($self, $target) = @_;
 
   my $target_class = 'App::SpreadRevolutionaryDate::Target::' . ucfirst(lc($target));
   my $target_meta;
@@ -192,8 +221,8 @@ sub check_target_mandatory_options {
 
 
 sub get_target_arguments {
-  my $self = shift;
-  my $target = lc(shift);
+  my ($self, $target) = @_;
+  $target = lc($target);
 
   my %target_args = $self->varlist("^${target}_", 1);
 
@@ -207,6 +236,22 @@ sub get_target_arguments {
 }
 
 
+sub get_msgmaker_arguments {
+  my ($self, $msgmaker) = @_;
+  $msgmaker = lc($msgmaker);
+
+  my %msgmaker_args = $self->varlist("^${msgmaker}_", 1);
+
+  # Add acab option for RevolutionaryDate for backward compatibility
+  $msgmaker_args{acab} = $self->acab
+    if  $msgmaker eq 'RevolutionaryDate'
+        && !exists($msgmaker_args{acab})
+        && $self->acab;
+
+  return %msgmaker_args;
+}
+
+
 no Moose;
 __PACKAGE__->meta->make_immutable(inline_constructor => 0);
 
@@ -229,7 +274,7 @@ App::SpreadRevolutionaryDate::Config - Companion class of L<App::SpreadRevolutio
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 METHODS
 
@@ -253,6 +298,10 @@ Checks whether target configuration options are set to authenticate on specified
 
 Takes one mandatory argument: C<target> as a string in lower case, without any underscore (like C<'twitter'>, C<'mastodon'> or C<'freenode'>). Returns a hash with configuration options relative to the passed C<target> argument. If C<test> option is true, any value for an option starting with C<"test_"> will be set for the option with the same name without C<"test_"> (eg. values of C<test_channels> are set to option C<channels> for C<Freenode> target).
 
+=head2 get_msgmaker_arguments
+
+Takes one mandatory argument: C<msgmaker> as a string. Returns a hash with configuration options relative to the passed C<msgmaker> argument.
+
 =head1 SEE ALSO
 
 =over
@@ -271,6 +320,12 @@ Takes one mandatory argument: C<target> as a string in lower case, without any u
 
 =item L<App::SpreadRevolutionaryDate::Target::Freenode::Bot>
 
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker>
+
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker::RevolutionaryDate>
+
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker::PromptUser>
+
 =back
 
 =head1 AUTHOR
